@@ -207,6 +207,7 @@ class CloudWatchEvent(PushEventSource):
         "Target": PropertyType(False, IS_DICT),
         "Enabled": PropertyType(False, IS_BOOL),
         "State": PropertyType(False, IS_STR),
+        "InputTransformer": PropertyType(False, IS_DICT),
     }
 
     EventBusName: Optional[PassThrough]
@@ -219,6 +220,7 @@ class CloudWatchEvent(PushEventSource):
     Target: Optional[PassThrough]
     Enabled: Optional[bool]
     State: Optional[PassThrough]
+    InputTransformer: Optional[PassThrough]
 
     @cw_timer(prefix=FUNCTION_EVETSOURCE_METRIC_PREFIX)
     def to_cloudformation(self, **kwargs):  # type: ignore[no-untyped-def]
@@ -291,6 +293,9 @@ class CloudWatchEvent(PushEventSource):
         if self.RetryPolicy is not None:
             target["RetryPolicy"] = self.RetryPolicy
 
+        if self.InputTransformer is not None:
+            target["InputTransformer"] = self.InputTransformer
+
         return target
 
 
@@ -485,7 +490,7 @@ class SNS(PushEventSource):
     property_types = {
         "Topic": PropertyType(True, IS_STR),
         "Region": PropertyType(False, IS_STR),
-        "FilterPolicy": PropertyType(False, dict_of(IS_STR, list_of(one_of(IS_STR, IS_DICT)))),
+        "FilterPolicy": PassThroughProperty(False),
         "FilterPolicyScope": PassThroughProperty(False),
         "SqsSubscription": PropertyType(False, one_of(IS_BOOL, IS_DICT)),
         "RedrivePolicy": PropertyType(False, IS_DICT),
