@@ -32,6 +32,7 @@ class Globals:
             "VpcConfig",
             "Environment",
             "Tags",
+            "PropagateTags",
             "Tracing",
             "KmsKeyArn",
             "AutoPublishAlias",
@@ -76,6 +77,7 @@ class Globals:
             "OpenApiVersion",
             "Domain",
             "AlwaysDeploy",
+            "PropagateTags",
         ],
         SamResourceType.HttpApi.value: [
             "Auth",
@@ -87,8 +89,10 @@ class Globals:
             "Domain",
             "RouteSettings",
             "FailOnWarnings",
+            "PropagateTags",
         ],
         SamResourceType.SimpleTable.value: ["SSESpecification"],
+        SamResourceType.StateMachine.value: ["PropagateTags"],
     }
     # unreleased_properties *must be* part of supported_properties too
     unreleased_properties: Dict[str, List[str]] = {
@@ -386,7 +390,7 @@ class GlobalProperties:
         if self.TOKEN.LIST == token_global == token_local:
             return self._merge_lists(global_value, local_value)  # type: ignore[no-untyped-call]
 
-        raise TypeError("Unsupported type of objects. GlobalType={}, LocalType={}".format(token_global, token_local))
+        raise TypeError(f"Unsupported type of objects. GlobalType={token_global}, LocalType={token_local}")
 
     def _merge_lists(self, global_list, local_list):  # type: ignore[no-untyped-def]
         """
@@ -477,4 +481,4 @@ class InvalidGlobalsSectionException(ExceptionWithMessage):
 
     @property
     def message(self) -> str:
-        return "'{}' section is invalid. {}".format(self._logical_id, self._message)
+        return f"'{self._logical_id}' section is invalid. {self._message}"
