@@ -1,10 +1,11 @@
-import pytest
-
+from typing import Any, List
 from unittest import TestCase
-from unittest.mock import Mock, call, ANY
-from samtranslator.model.exceptions import InvalidResourceException
-from samtranslator.model import PropertyType, Resource, SamResourceMacro, ResourceTypeResolver
+from unittest.mock import Mock
+
+import pytest
 from samtranslator.intrinsics.resource_refs import SupportedResourceReferences
+from samtranslator.model import PropertyType, Resource, ResourceTypeResolver, SamResourceMacro
+from samtranslator.model.exceptions import InvalidResourceException
 from samtranslator.plugins import LifeCycleEvents
 
 
@@ -129,8 +130,7 @@ class TestResourceAttributes(TestCase):
         self.assertEqual(r.to_dict(), dict_with_attributes2)
 
     def test_invalid_attr(self):
-
-        with pytest.raises(KeyError) as ex:
+        with pytest.raises(KeyError):
             # Unsupported attributes cannot be added to the resource
             self.MyResource("id", attributes={"foo": "bar"})
 
@@ -220,6 +220,9 @@ class TestSamResourceReferableProperties(TestCase):
             property_types = {}
             referable_properties = {"prop1": "resource_type1", "prop2": "resource_type2", "prop3": "resource_type3"}
 
+            def to_cloudformation(self, **kwargs: Any) -> List[Any]:
+                return []
+
         sam_resource = NewSamResource("SamLogicalId")
 
         cfn_resources = [self.ResourceType1("logicalId1"), self.ResourceType2("logicalId2")]
@@ -241,6 +244,9 @@ class TestSamResourceReferableProperties(TestCase):
             property_types = {}
             referable_properties = {"prop1": "resource_type1", "prop2": "resource_type2", "prop3": "resource_type3"}
 
+            def to_cloudformation(self, **kwargs: Any) -> List[Any]:
+                return []
+
         sam_resource1 = NewSamResource("SamLogicalId1")
         sam_resource2 = NewSamResource("SamLogicalId2")
 
@@ -267,6 +273,9 @@ class TestSamResourceReferableProperties(TestCase):
             property_types = {}
             referable_properties = {"prop1": "foo", "prop2": "bar"}
 
+            def to_cloudformation(self, **kwargs: Any) -> List[Any]:
+                return []
+
         sam_resource = NewSamResource("SamLogicalId")
 
         # None of the CFN resource types are in the referable list
@@ -282,6 +291,9 @@ class TestSamResourceReferableProperties(TestCase):
             property_types = {}
             referable_properties = {}
 
+            def to_cloudformation(self, **kwargs: Any) -> List[Any]:
+                return []
+
         sam_resource = NewSamResource("SamLogicalId")
 
         cfn_resources = [self.ResourceType1("logicalId1"), self.ResourceType2("logicalId2")]
@@ -296,6 +308,9 @@ class TestSamResourceReferableProperties(TestCase):
             property_types = {}
             referable_properties = {"prop1": "resource_type1"}
 
+            def to_cloudformation(self, **kwargs: Any) -> List[Any]:
+                return []
+
         sam_resource = NewSamResource("SamLogicalId")
 
         cfn_resources = []
@@ -310,6 +325,9 @@ class TestSamResourceReferableProperties(TestCase):
             property_types = {}
             referable_properties = {"prop1": "resource_type1"}
 
+            def to_cloudformation(self, **kwargs: Any) -> List[Any]:
+                return []
+
         sam_resource = NewSamResource("SamLogicalId")
 
         cfn_resources = [self.ResourceType1("logicalId1")]
